pub struct ApprovalList {
pub items: Option<Vec<Approval>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
}Expand description
The response of an Approvals list request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list approvals (response)
Fields
items: Option<Vec<Approval>>The list of Approvals. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched.
kind: Option<String>This is always drive#approvalList
next_page_token: Option<String>The page token for the next page of Approvals. This will be absent if the end of the Approvals list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results.