Struct google_drive3::api::CommentQuotedFileContent [−][src]
The file content to which the comment refers, typically within the anchor region. For a text file, for example, this would be the text at the location of the comment.
This type is not used in any activity, and only used as part of another schema.
Fields
mime_type: Option<String>The MIME type of the quoted content.
value: Option<String>The quoted content itself. This is interpreted as plain text if set through the API.