pub struct DownloadRestriction {
pub restricted_for_readers: Option<bool>,
pub restricted_for_writers: Option<bool>,
}Expand description
A restriction for copy and download of the file.
This type is not used in any activity, and only used as part of another schema.
Fields
restricted_for_readers: Option<bool>Whether download and copy is restricted for readers.
restricted_for_writers: Option<bool>Whether download and copy is restricted for writers. If true, download is also restricted for readers.