pub struct DownloadRestrictionsMetadata {
pub effective_download_restriction_with_context: Option<DownloadRestriction>,
pub item_download_restriction: Option<DownloadRestriction>,
}Expand description
Download restrictions applied to the file.
This type is not used in any activity, and only used as part of another schema.
Fields
effective_download_restriction_with_context: Option<DownloadRestriction>Output only. The effective download restriction applied to this file. This considers all restriction settings and DLP rules.
item_download_restriction: Option<DownloadRestriction>The download restriction of the file applied directly by the owner or organizer. This doesn’t take into account shared drive settings or DLP rules.