pub struct ListAccessProposalsResponse {
pub access_proposals: Option<Vec<AccessProposal>>,
pub next_page_token: Option<String>,
}Expand description
The response to an access proposal list request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list accessproposals (response)
Fields
access_proposals: Option<Vec<AccessProposal>>The list of access proposals. This field is only populated in Drive API v3.
next_page_token: Option<String>The continuation token for the next page of results. This will be absent if the end of the results list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results.