Struct google_drive3::api::Revision[][src]

pub struct Revision {
    pub export_links: Option<HashMap<String, String>>,
    pub id: Option<String>,
    pub keep_forever: Option<bool>,
    pub kind: Option<String>,
    pub last_modifying_user: Option<User>,
    pub md5_checksum: Option<String>,
    pub mime_type: Option<String>,
    pub modified_time: Option<String>,
    pub original_filename: Option<String>,
    pub publish_auto: Option<bool>,
    pub published: Option<bool>,
    pub published_link: Option<String>,
    pub published_outside_domain: Option<bool>,
    pub size: Option<String>,
}

The metadata for a revision to a file.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

export_links: Option<HashMap<String, String>>

Links for exporting Docs Editors files to specific formats.

id: Option<String>

The ID of the revision.

keep_forever: Option<bool>

Whether to keep this revision forever, even if it is no longer the head revision. If not set, the revision will be automatically purged 30 days after newer content is uploaded. This can be set on a maximum of 200 revisions for a file. This field is only applicable to files with binary content in Drive.

kind: Option<String>

Identifies what kind of resource this is. Value: the fixed string “drive#revision”.

last_modifying_user: Option<User>

The last user to modify this revision.

md5_checksum: Option<String>

The MD5 checksum of the revision’s content. This is only applicable to files with binary content in Drive.

mime_type: Option<String>

The MIME type of the revision.

modified_time: Option<String>

The last time the revision was modified (RFC 3339 date-time).

original_filename: Option<String>

The original filename used to create this revision. This is only applicable to files with binary content in Drive.

publish_auto: Option<bool>

Whether subsequent revisions will be automatically republished. This is only applicable to Docs Editors files.

published: Option<bool>

Whether this revision is published. This is only applicable to Docs Editors files.

published_link: Option<String>

A link to the published revision. This is only populated for Google Sites files.

published_outside_domain: Option<bool>

Whether this revision is published outside the domain. This is only applicable to Docs Editors files.

size: Option<String>

The size of the revision’s content in bytes. This is only applicable to files with binary content in Drive.