Struct google_drive3::FileContentHintsThumbnail [−][src]
A thumbnail for the file. This will only be used if Drive cannot generate a standard thumbnail.
This type is not used in any activity, and only used as part of another schema.
Fields
mime_type: Option<String>
The MIME type of the thumbnail.
image: Option<String>
The thumbnail data encoded with URL-safe Base64 (RFC 4648 section 5).