Trait google_drive3::NestedType [−][src]
pub trait NestedType { }Identifies types which are only used by other types internally. They have no special meaning, this trait just marks them for completeness.
Implementors
impl NestedType for PermissionTeamDrivePermissionDetailsimpl NestedType for AboutTeamDriveThemesimpl NestedType for TeamDriveCapabilitiesimpl NestedType for TeamDriveBackgroundImageFileimpl NestedType for FileVideoMediaMetadataimpl NestedType for FileContentHintsThumbnailimpl NestedType for FileImageMediaMetadataimpl NestedType for CommentQuotedFileContentimpl NestedType for FileContentHintsimpl NestedType for FileImageMediaMetadataLocationimpl NestedType for FileCapabilitiesimpl NestedType for TeamDriveRestrictionsimpl NestedType for AboutStorageQuota