pub struct AboutStorageQuota {
pub limit: Option<i64>,
pub usage: Option<i64>,
pub usage_in_drive: Option<i64>,
pub usage_in_drive_trash: Option<i64>,
}Expand description
The user’s storage quota limits and usage. For users that are part of an organization with pooled storage, information about the limit and usage across all services is for the organization, rather than the individual user. All fields are measured in bytes.
This type is not used in any activity, and only used as part of another schema.
Fields
limit: Option<i64>The usage limit, if applicable. This will not be present if the user has unlimited storage. For users that are part of an organization with pooled storage, this is the limit for the organization, rather than the individual user.
usage: Option<i64>The total usage across all services. For users that are part of an organization with pooled storage, this is the usage across all services for the organization, rather than the individual user.
usage_in_drive: Option<i64>The usage by all files in Google Drive.
usage_in_drive_trash: Option<i64>The usage by trashed files in Google Drive.