Struct google_drive3::api::Comment [−][src]
A comment on a file.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- create comments (request|response)
- delete comments (none)
- get comments (response)
- list comments (none)
- update comments (request|response)
Fields
anchor: Option<String>A region of the document represented as a JSON string. See anchor documentation for details on how to define and interpret anchor properties.
The author of the comment. The author’s email address and permission ID will not be populated.
content: Option<String>The plain text content of the comment. This field is used for setting the content, while htmlContent should be displayed.
created_time: Option<String>The time at which the comment was created (RFC 3339 date-time).
deleted: Option<bool>Whether the comment has been deleted. A deleted comment has no content.
html_content: Option<String>The content of the comment with HTML formatting.
id: Option<String>The ID of the comment.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “drive#comment”.
modified_time: Option<String>The last time the comment or any of its replies was modified (RFC 3339 date-time).
quoted_file_content: Option<CommentQuotedFileContent>The file content to which the comment refers, typically within the anchor region. For a text file, for example, this would be the text at the location of the comment.
replies: Option<Vec<Reply>>The full list of replies to the comment in chronological order.
resolved: Option<bool>Whether the comment has been resolved by one of its replies.