Struct google_drive3::api::DriveList [−][src]
A list of shared drives.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list drives (response)
Fields
drives: Option<Vec<Drive>>The list of shared drives. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “drive#driveList”.
next_page_token: Option<String>The page token for the next page of shared drives. This will be absent if the end of the list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results.