[−][src]Struct google_drive3::Reply
A reply to a comment on a file.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- create replies (request|response)
- get replies (response)
- update replies (request|response)
Fields
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string "drive#reply".
modified_time: Option<String>The last time the reply was modified (RFC 3339 date-time).
The author of the reply. The author's email address and permission ID will not be populated.
deleted: Option<bool>Whether the reply has been deleted. A deleted reply has no content.
html_content: Option<String>The content of the reply with HTML formatting.
content: Option<String>The plain text content of the reply. This field is used for setting the content, while htmlContent should be displayed. This is required on creates if no action is specified.
action: Option<String>The action the reply performed to the parent comment. Valid values are:
- resolve
- reopen
created_time: Option<String>The time at which the reply was created (RFC 3339 date-time).
id: Option<String>The ID of the reply.